@@ -8,23 +8,20 @@ This module contains the set of Waybackpy's exceptions.
 class WaybackError(Exception):
     """
     Raised when Waybackpy can not return what you asked for.
-     1) Wayback Machine API Service is unreachable/down.
-     2) You passed illegal arguments.
 
-     All other exceptions are inherited from this class.
+    1) Wayback Machine API Service is unreachable/down.
+    2) You passed illegal arguments.
+
+    All other exceptions are inherited from this main exception.
     """
 
 
-class RedirectSaveError(WaybackError):
-    """
-    Raised when the original URL is redirected and the
-    redirect URL is archived but not the original URL.
+class TooManyRequestsError(WaybackError):
     """
+    Raised when you make more than 15 requests per
+    minute and the Wayback Machine returns 429.
 
-
-class URLError(Exception):
-    """
-    Raised when malformed URLs are passed as arguments.
+    See https://github.com/akamhy/waybackpy/issues/131
     """
 
 
